@@ -7,7 +7,7 @@
 **
 ** Copyright (C) 1992-1999 Troll Tech AS.  All rights reserved.
 **
-** This file is part of Qt Free Edition, version 1.44.
+** This file is part of Qt Free Edition, version 1.45.
 **
 ** See the file LICENSE included in the distribution for the usage
 ** and distribution terms, or http://www.troll.no/free-license.html.
@@ -15,7 +15,7 @@
 ** IMPORTANT NOTE: You may NOT copy this file or any part of it into
 ** your own programs or libraries.
 **
-** Please see http://www.troll.no/pricing.html for information about 
+** Please see http://www.troll.no/pricing.html for information about
 ** Qt Professional Edition, which is this same library but with a
 ** license which allows creation of commercial/proprietary software.
 **
@@ -2070,7 +2070,7 @@ void QPSPrinter::setFont( const QFont & f )
 	if ( postscriptFontNames[i].italic )
 	    ps = postscriptFontNames[i].italic;
 	else
-	    ps.append( "-Italic" );
+	    ps.append( "-Italic" ); // possibly suboptimal
     } else if ( weight <= QFont::Light && italic ) {
 	if ( postscriptFontNames[i].lightItalic )
 	    ps = postscriptFontNames[i].lightItalic;
@@ -2081,6 +2081,11 @@ void QPSPrinter::setFont( const QFont & f )
 	    ps = postscriptFontNames[i].light;
 	else
 	    ps.append( "-Light" );
+    } else if ( italic ) {
+	if ( postscriptFontNames[i].italic )
+	    ps = postscriptFontNames[i].italic;
+	else
+	    ps.append( "-Italic" );
     } else {
 	if ( postscriptFontNames[i].roman )
 	    ps = postscriptFontNames[i].roman;
@@ -2296,7 +2301,7 @@ bool QPSPrinter::cmd( int c , QPainter *paint, QPDevCmdParam *p )
 	d->firstClipOnPage  = TRUE;
 	d->boundingBox = QRect( 0, 0, -1, -1 );
 	fontsUsed = "";
-	
+
 	stream << "%%Page: " << pageCount << ' ' << pageCount << endl
 	       << "QI\n";
 	orientationSetup();
@@ -2449,7 +2454,7 @@ bool QPSPrinter::cmd( int c , QPainter *paint, QPDevCmdParam *p )
 	    if ( p[1].pixmap->isNull() )
 		break;
 	    QPoint pnt = *(p[0].point);
-	    QImage img;	
+	    QImage img;
 	    img = *(p[1].pixmap);
 	    drawImage( paint, pnt, img );
 	    break;
